package cn.com.ty.lift.business.library.service;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.LiftExtension;
import cn.com.ty.lift.business.library.dao.entity.ProjectLiftRelevance;
import cn.com.ty.lift.business.library.dao.entity.model.BatchUpdateLiftRequest;
import cn.com.ty.lift.business.library.dao.mapper.ProjectLiftRelevanceMapper;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

/**
 * @author bieao
 * @date 2019/12/5
 * @description 项目电梯关联业务层
 */
@Service
public class ProjectLiftRelevanceService extends ServiceImpl<ProjectLiftRelevanceMapper, ProjectLiftRelevance> {

    /**
     * @param request updateLiftList 批量更新列表
     * @return RestResponse 状态码和返回消息
     * @description 电梯批量锁定、解锁
     * @date 2019/12/5 11:00 AM
     */
    public RestResponse lockOrUnlock(BatchUpdateLiftRequest request) {
        boolean result = updateBatchById(request.getUpdateLiftList());
        if (!result) {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.batch.fail"));
        }
        return RestResponse.ok(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.batch.success"));
    }

    /**
     * @param id 主键id
     * @return RestResponse 状态码和返回消息
     * @description 逻辑删除电梯
     * @date 2019/12/5 2:16 PM
     */
    public RestResponse logicDelete(long id) {
        boolean result = removeById(id);
        if (!result) {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
        }
        return RestResponse.ok(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
    }

    /**
     * @param extension 电梯扩展
     * @param id        平台企业电梯主键id
     * @param workerId  维保工id
     * @return projectLiftEntry
     * @description 新增项目电梯关联数据
     * @date 2019/12/5 2:39 PM
     */
    public boolean save(LiftExtension extension, long id, long workerId) {
        //新增项目电梯关联表
        ProjectLiftRelevance projectLiftEntry = new ProjectLiftRelevance();
        projectLiftEntry.setProjectId(extension.getProjectId());
        projectLiftEntry.setLiftId(extension.getId());
        projectLiftEntry.setRelevanceId(id);
        projectLiftEntry.setUserId(workerId);
        return save(projectLiftEntry);
    }

    /**
     * @param relevance
     * @return RestResponse 状态码和返回消息
     * @description 项目锁定、解锁
     * @date 2019/12/5 11:00 AM
     */
    public RestResponse lockOrUnlock(ProjectLiftRelevance relevance) {
        boolean result = updateById(relevance);
        if (!result) {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
        }
        return RestResponse.ok(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
    }
}
