package cn.com.ty.lift.business.project.controller;

import cn.com.ty.lift.business.library.dao.entity.ProjectLiftRelevance;
import cn.com.ty.lift.business.library.service.ProjectLiftRelevanceService;
import cn.com.ty.lift.business.project.dao.entity.Project;
import cn.com.ty.lift.business.project.dao.entity.ProjectHistory;
import cn.com.ty.lift.business.project.dao.entity.ProjectUser;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectHistoryRequest;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectRequest;
import cn.com.ty.lift.business.project.service.ProjectService;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * @author bieao
 * @date 2019/11/28
 * @description 项目管理控制层
 */
@RestController
@RequestMapping("project")
public class ProjectController {

    @Resource
    private ProjectService projectService;

    @Resource
    private ProjectLiftRelevanceService projectLiftRelevanceService;

    /**
     * @param request 项目列表查询条件
     * @return RestResponse<IPage<Project>> 项目分页列表结果
     * @description 查询项目列表
     * @date 2019/11/28 4:18 PM
     */
    @PostMapping("list")
    public RestResponse<IPage<Project>> list(@RequestBody ProjectRequest request) {
        return projectService.list(request);
    }

    /**
     * @param request 项目操作记录查询条件
     * @return RestResponse<IPage<ProjectHistory>> 项目操作记录分页列表结果
     * @description 查询项目操作记录列表
     * @date 2019/12/2 11:41 AM
     */
    @PostMapping("history/list")
    public RestResponse<IPage<ProjectHistory>> list(@RequestBody ProjectHistoryRequest request) {
        return projectService.list(request);
    }

    /**
     * @return RestResponse 省、市、区树形结构列表
     * @description 查询省、市、区树形结构列表
     * @date 2019/12/4 10:23 AM
     */
    @PostMapping("area/list")
    public RestResponse areaList() {
        return projectService.areaList();
    }

    /**
     * @param project 新增项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody Project project) {
        return projectService.add(project);
    }

    /**
     * @param projectUser 新增维保工数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增维保工
     * @date 2019/12/4 4:44 PM
     */
    @PostMapping("worker/add")
    public RestResponse add(@RequestBody ProjectUser projectUser) {
        return projectService.add(projectUser);
    }

    /**
     * @param project 修改项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 修改项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody Project project) {
        return projectService.modify(project);
    }

    /**
     * @param relevance
     * @return 1.成功, 0.失败, 消息描述
     * @description 项目锁定、解锁
     * @date 2019/12/5 4:16 PM
     */
    @PostMapping("lockOrUnlock")
    public RestResponse lockOrUnlock(@RequestBody ProjectLiftRelevance relevance) {
        return projectLiftRelevanceService.lockOrUnlock(relevance);
    }

    /**
     * @param request 导出项目数据列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 导出项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("export")
    public void export(@RequestBody ExportRequest request) {
        projectService.export(request);
    }
}